slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDView

Prints the SVD data structure.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDView(SVD svd,PetscViewer viewer)

Collective on svd

### Input Parameters

| svd | - the singular value solver context
| viewer | - optional visualization context

### Options Database Key

| -svd_view | - Calls SVDView() at end of SVDSolve()

### Note

The available visualization contexts include

| PETSC_VIEWER_STDOUT_SELF | - standard output (default)
| PETSC_VIEWER_STDOUT_WORLD | - synchronized standard output where only the first processor opens the file. All other processors send their data to the first processor to print.

The user can open an alternative visualization context with PetscViewerASCIIOpen() - output to a specified file.

### See Also

EPSView()

### Level

beginner

### Location

src/svd/interface/svdview.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages